@@ -17,8 +17,8 @@
 #with this program; if not, write to the Free Software Foundation, Inc.,
 #51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
-from fiabili.system import System, Component, Voter
-from fiabili.markov import Markovprocess
+from fiabilipy.system import System, Component, Voter
+from fiabilipy.markov import Markovprocess
 
 __all__ = ['System', 'Component', 'Voter', 'Markovprocess']
 __version__ = '2.2'
